UpdateManager - Rabbyt Reference

Documentation Index | From module rabbyt.physics.

# UpdateManager

`UpdateManager()`

I am planning on taking this class out in the next version of rabbyt. If you want it to stay, drop me an email explaining why and I might change my mind.

This is a small helper class for keeping track of physics drivers that need updated.

All physics drivers are stored as weakrefs, so you don't need to worry about removing them.

There is a global update manager at `rabbyt.physics.default_update_manager`. All physics drivers are automatically added to it.

## Methods

### append

### remove_ref

### update

`update(dt)`

Update the physics drivers by timestep `dt`.